@@ -57,6 +57,7 @@ pub fn publish(
     features: &Features,
     registry: Option<&str>,
     token: Option<&str>,
+    target: Option<&str>,
 ) -> Result<bool, FatalError> {
     let cargo = cargo();
 
@@ -86,6 +87,11 @@ pub fn publish(
         command.push("--no-verify");
     }
 
+    if let Some(target) = target {
+        command.push("--target");
+        command.push(target);
+    }
+
     let feature_arg;
     match features {
         Features::None => (),
